@@ -16,6 +16,7 @@ import random
 import re
 import string
 import warnings
+from collections.abc import Mapping
 from decimal import Decimal
 from types import ModuleType
 from typing import (
@@ -37,6 +38,7 @@ from urllib.parse import quote
 
 import cognite.client
 from cognite.client.exceptions import CogniteImportError
+from cognite.client.utils._identifier import T_ID, Identifier
 from cognite.client.utils._version_checker import get_newest_version_in_major_release
 
 T = TypeVar("T")
@@ -59,6 +61,13 @@ def to_snake_case(camel_case_string: str) -> str:
     return re.sub("([a-z0-9])([A-Z])", r"\1_\2", s1).lower()
 
 
+def iterable_to_case(seq: Sequence[str], camel_case: bool) -> Iterator[str]:
+    if camel_case:
+        yield from map(to_camel_case, seq)
+    else:
+        yield from map(to_snake_case, seq)
+
+
 def convert_all_keys_to_camel_case(d: Dict[str, Any]) -> Dict[str, Any]:
     return dict(zip(map(to_camel_case, d.keys()), d.values()))
 
@@ -73,28 +82,39 @@ def basic_obj_dump(obj: Any, camel_case: bool) -> Dict[str, Any]:
     return convert_all_keys_to_snake_case(vars(obj))
 
 
-def handle_deprecated_camel_case_argument(new_arg: T, old_arg_name: str, fn_name: str, kw_dct: Dict[str, Any]) -> T:
+def handle_renamed_argument(
+    new_arg: T,
+    new_arg_name: str,
+    old_arg_name: str,
+    fn_name: str,
+    kw_dct: Dict[str, Any],
+    required: bool = True,
+) -> T:
     old_arg = kw_dct.pop(old_arg_name, None)
     if kw_dct:
         raise TypeError(f"Got unexpected keyword argument(s): {list(kw_dct)}")
 
-    new_arg_name = to_snake_case(old_arg_name)
     if old_arg is None:
-        if new_arg is None:
-            raise TypeError(f"{fn_name}() missing 1 required positional argument: '{new_arg_name}'")
+        if new_arg is None and required:
+            raise TypeError(f"{fn_name}() missing 1 required positional argument: {new_arg_name!r}")
         return new_arg
 
     warnings.warn(
-        f"Argument '{old_arg_name}' have been changed to '{new_arg_name}', but the old is still supported until "
+        f"Argument {old_arg_name!r} have been changed to {new_arg_name!r}, but the old is still supported until "
         "the next major version. Consider updating your code.",
         UserWarning,
         stacklevel=2,
     )
     if new_arg is not None:
-        raise TypeError(f"Pass either '{new_arg_name}' or '{old_arg_name}' (deprecated), not both")
+        raise TypeError(f"Pass either {new_arg_name!r} or {old_arg_name!r} (deprecated), not both")
     return old_arg
 
 
+def handle_deprecated_camel_case_argument(new_arg: T, old_arg_name: str, fn_name: str, kw_dct: Dict[str, Any]) -> T:
+    new_arg_name = to_snake_case(old_arg_name)
+    return handle_renamed_argument(new_arg, new_arg_name, old_arg_name, fn_name, kw_dct)
+
+
 def json_dump_default(x: Any) -> Any:
     if isinstance(x, numbers.Integral):
         return int(x)
@@ -124,6 +144,24 @@ def assert_type(var: Any, var_name: str, types: List[type], allow_none: bool = F
         raise TypeError(f"{var_name} must be one of types {types}")
 
 
+def validate_user_input_dict_with_identifier(dct: Mapping, required_keys: Set[str]) -> Dict[str, T_ID]:
+    if not isinstance(dct, Mapping):
+        raise TypeError(f"Expected dict-like object, got {type(dct)}")
+
+    # Verify that we have gotten exactly one identifier:
+    xid = dct.get("externalId") or dct.get("external_id")
+    id_dct = Identifier.of_either(dct.get("id"), xid).as_dict(camel_case=True)
+
+    missing_keys = required_keys.difference(dct)
+    invalid_keys = set(dct) - required_keys - {"id", "externalId", "external_id"}
+    if missing_keys or invalid_keys:
+        raise ValueError(
+            f"Given dictionary failed validation. Invalid key(s): {sorted(invalid_keys)}, "
+            f"required key(s) missing: {sorted(missing_keys)}."
+        )
+    return id_dct
+
+
 def interpolate_and_url_encode(path: str, *args: Any) -> str:
     return path.format(*[quote(str(arg), safe="") for arg in args])
 
